@@ -45,7 +45,7 @@ class ConsoleFormatter(BaseFormatter):
         lines = []
         
         if event.event_type == 'file.create':
-            lines.append(f"\n[*] [File] File Creation:")
+            lines.append("\n[*] [File] File Creation:")
             lines.append(f"[*] Operation: {event.operation or 'Unknown'}")
             lines.append(f"[*] File Path: {event.file_path or 'Unknown'}")
             if event.parent_path:
@@ -53,13 +53,13 @@ class ConsoleFormatter(BaseFormatter):
                 lines.append(f"[*] Child: {event.child_path}")
         
         elif event.event_type == 'file.stream.create':
-            lines.append(f"\n[*] [File] Stream Creation:")
+            lines.append("\n[*] [File] Stream Creation:")
             lines.append(f"[*] Operation: {event.operation or 'Unknown'}")
             lines.append(f"[*] Stream Type: {event.stream_type or 'Unknown'}")
             lines.append(f"[*] File Path: {event.file_path or 'Unknown'}")
         
         elif event.event_type == 'file.read':
-            lines.append(f"\n[*] [File] Read Operation:")
+            lines.append("\n[*] [File] Read Operation:")
             lines.append(f"[*] Operation: {event.operation or 'Unknown'}")
             lines.append(f"[*] File Path: {event.file_path or 'Unknown'}")
             lines.append(f"[*] Buffer Size: {event.buffer_size or 0} bytes")
@@ -68,9 +68,14 @@ class ConsoleFormatter(BaseFormatter):
             if event.bytes_read:
                 lines.append(f"[*] Bytes Read: {event.bytes_read}")
             
-            # Display data if available
-            if event.hexdump_display:
-                lines.append(f"[*] Data:")
+            # Display data if available (truncated for terminal)
+            if event.data_hex:
+                lines.append("[*] Data:")
+                data_dump = hexdump(event.data_hex, header=True, ansi=True, truncate=True, max_bytes=0x50)
+                for line in data_dump.split('\n'):
+                    lines.append(f"    {line}")
+            elif event.hexdump_display:
+                lines.append("[*] Data:")
                 for line in event.hexdump_display.split('\n'):
                     lines.append(f"    {line}")
             elif event.plaintext:
@@ -78,7 +83,7 @@ class ConsoleFormatter(BaseFormatter):
                 lines.append(f"[*] Content: {plaintext}")
         
         elif event.event_type == 'file.write':
-            lines.append(f"\n[*] [File] Write Operation:")
+            lines.append("\n[*] [File] Write Operation:")
             lines.append(f"[*] Operation: {event.operation or 'Unknown'}")
             lines.append(f"[*] File Path: {event.file_path or 'Unknown'}")
             lines.append(f"[*] Buffer Size: {event.buffer_size or 0} bytes")
@@ -87,16 +92,17 @@ class ConsoleFormatter(BaseFormatter):
             if event.is_large_data:
                 lines.append(f"[*] Data truncated (showing {getattr(event, 'displayed_length', 0)} of {getattr(event, 'original_length', 0)} bytes)")
             
-            # Display data based on file type
+            # Display data based on file type (truncated for terminal)
             if event.file_type == 'xml' and event.plaintext:
                 plaintext = truncate_string(event.plaintext, 200)
                 lines.append(f"[*] XML Content: {plaintext}")
-            elif event.file_type == 'binary' and event.hexdump_display:
-                lines.append(f"[*] Binary Data:")
-                for line in event.hexdump_display.split('\n'):
+            elif event.data_hex:
+                lines.append("[*] Binary Data:" if event.file_type == 'binary' else "[*] Data:")
+                data_dump = hexdump(event.data_hex, header=True, ansi=True, truncate=True, max_bytes=0x50)
+                for line in data_dump.split('\n'):
                     lines.append(f"    {line}")
             elif event.hexdump_display:
-                lines.append(f"[*] Data:")
+                lines.append("[*] Data:")
                 for line in event.hexdump_display.split('\n'):
                     lines.append(f"    {line}")
             elif event.plaintext:
@@ -121,45 +127,45 @@ class ConsoleFormatter(BaseFormatter):
         if event.event_type == 'crypto.cipher.operation':
             lines.append(f"\n[*] AES {event.operation_mode_desc or 'UNKNOWN'} Operation:")
             lines.append(f"    Algorithm: {event.algorithm or 'N/A'}")
-            
-            # Display input data with hexdump
+
+            # Display input data with hexdump (truncated for terminal, full in JSON)
             if event.input_hex:
                 lines.append(f"    Input ({event.input_length or 0} bytes):")
-                input_dump = hexdump(event.input_hex, header=True, ansi=True)
+                input_dump = hexdump(event.input_hex, header=True, ansi=True, truncate=True, max_bytes=0x50)
                 if input_dump:
                     for line in input_dump.split('\n'):
                         lines.append(f"      {line}")
-            
-            # Display output data with hexdump  
+
+            # Display output data with hexdump (truncated for terminal, full in JSON)
             if event.output_hex:
                 lines.append(f"    Output ({event.output_length or 0} bytes):")
-                output_dump = hexdump(event.output_hex, header=True, ansi=True)
+                output_dump = hexdump(event.output_hex, header=True, ansi=True, truncate=True, max_bytes=0x50)
                 if output_dump:
                     for line in output_dump.split('\n'):
                         lines.append(f"      {line}")
-            
+
             # Display plaintext if available (truncated for terminal)
             if event.plaintext:
                 plaintext = truncate_string(event.plaintext, 100)
                 lines.append(f"    Plaintext: {plaintext}")
         
         elif event.event_type == 'crypto.key.creation':
-            lines.append(f"[*] AES Key Created:")
+            lines.append("[*] AES Key Created:")
             lines.append(f"    Algorithm: {event.algorithm or 'N/A'}")
             lines.append(f"    Key Length: {event.key_length or 0} bytes")
             if event.key_hex:
-                lines.append(f"    Key:")
-                key_dump = hexdump(event.key_hex, header=True, ansi=True)
+                lines.append("    Key:")
+                key_dump = hexdump(event.key_hex, header=True, ansi=True, truncate=True, max_bytes=0x50)
                 if key_dump:
                     for line in key_dump.split('\n'):
                         lines.append(f"      {line}")
-        
+
         elif event.event_type == 'crypto.iv.creation':
-            lines.append(f"[*] AES IV Created:")
+            lines.append("[*] AES IV Created:")
             lines.append(f"    IV Length: {event.iv_length or 0} bytes")
             if event.iv_hex:
-                lines.append(f"    IV:")
-                iv_dump = hexdump(event.iv_hex, header=True, ansi=True)
+                lines.append("    IV:")
+                iv_dump = hexdump(event.iv_hex, header=True, ansi=True, truncate=True, max_bytes=0x50)
                 if iv_dump:
                     for line in iv_dump.split('\n'):
                         lines.append(f"      {line}")
@@ -226,7 +232,7 @@ class ConsoleFormatter(BaseFormatter):
                 lines.append(f"[*] Data Length: {event.data_length} bytes")
                 
             if event.has_buffer:
-                lines.append(f"[*] Buffer Data: Available")
+                lines.append("[*] Buffer Data: Available")
         
         else:
             lines.append(f"[*] [Network] {event.event_type}: {getattr(event, 'url', '') or getattr(event, 'uri', '') or 'Unknown'}")
@@ -239,7 +245,7 @@ class ConsoleFormatter(BaseFormatter):
         lines = []
         
         if event.event_type == 'process.creation':
-            lines.append(f"\n[*] [Process] New Process Creation:")
+            lines.append("\n[*] [Process] New Process Creation:")
             if event.nice_name:
                 lines.append(f"[*] Process Name: {event.nice_name}")
             if event.uid is not None:
@@ -276,7 +282,7 @@ class ConsoleFormatter(BaseFormatter):
                 lines.append(f"[*] Return Value: {event.return_value}")
         
         elif event.event_type == 'runtime.exec':
-            lines.append(f"\n[*] [Runtime] Command Execution:")
+            lines.append("\n[*] [Runtime] Command Execution:")
             if event.command:
                 lines.append(f"[*] Command: {event.command}")
             if event.working_directory:
@@ -326,7 +332,7 @@ class ConsoleFormatter(BaseFormatter):
                 lines.append(f"[*] Signature: {event.metadata['method_signature']}")
         
         elif event.event_type == 'reflection.method_invoke':
-            lines.append(f"\n[*] [Reflection] Method Invoke:")
+            lines.append("\n[*] [Reflection] Method Invoke:")
             if 'method_name' in event.metadata:
                 lines.append(f"[*] Method: {event.metadata['method_name']}")
             if 'target_instance' in event.metadata:
@@ -388,7 +394,7 @@ class ConsoleFormatter(BaseFormatter):
                 if intent_info.get('mime_type'):
                     lines.append(f"[*] MIME Type: {intent_info['mime_type']}")
             if event.extras_formatted:
-                lines.append(f"[*] Extras:")
+                lines.append("[*] Extras:")
                 for extra in event.extras_formatted:
                     lines.append(f"    {extra}")
         
@@ -484,13 +490,43 @@ class ConsoleFormatter(BaseFormatter):
     def _format_dex_event(self, event: DEXEvent) -> str:
         """Format DEX events"""
         lines = []
-        
+
+        # Handle legacy format
         if event.event_type == "dex.loading" and event.even_type:
             lines.append(f"[*] Method used for unpacking: {event.even_type}")
+
+        # Handle new structured events
+        elif event.event_type == "dex.unpacking.detected":
+            if hasattr(event, 'hooked_function') and event.hooked_function:
+                # Extract just the function name from demangled format
+                func_parts = str(event.hooked_function).split("::")
+                func_name = func_parts[-1] if len(func_parts) > 1 else event.hooked_function
+                lines.append(f"[*] Method used for unpacking: {func_name}")
+            if hasattr(event, 'magic') and event.magic:
+                lines.append(f"[*] Magic: {event.magic}")
+            if hasattr(event, 'size') and event.size:
+                lines.append(f"[*] Size: {event.size}")
+            if hasattr(event, 'original_location') and event.original_location:
+                lines.append(f"[*] Original location: {event.original_location}")
+
+        elif event.event_type.startswith("dex.classloader."):
+            loader_type = getattr(event, 'class_loader_type', 'Unknown')
+            file_path = getattr(event, 'file_path', 'Unknown')
+            lines.append(f"[*] {loader_type} loading: {file_path}")
+
+        elif event.event_type == "dex.in_memory_loader":
+            buffer_size = getattr(event, 'buffer_size', 'Unknown')
+            lines.append(f"[*] InMemoryDexClassLoader: {buffer_size} bytes")
+
+        elif event.event_type == "dex.dump_success":
+            file_name = getattr(event, 'file_name', 'Unknown')
+            bytes_written = getattr(event, 'bytes_written', 'Unknown')
+            lines.append(f"[*] Dumped successfully: {file_name} ({bytes_written} bytes)")
+
         else:
             lines.append(f"[*] DEX: {event.event_type}")
-        
-        return '\n'.join(lines)
+
+        return '\n'.join(lines) if lines else ""
     
     def _format_generic_event(self, event: Event) -> str:
         """Format generic events"""
